@@ -46,7 +46,9 @@ def adjust_gitignore(repo_root: Path) -> None:
         ".ai",
         "GEMINI.md",
         "CLAUDE.md",
+        "CRUSH.md",
         ".cursor",
+        ".clinerules"
         ".github/instructions",
         ".github/chatmodes",
         ".github/prompts",
