@@ -46,6 +46,7 @@ console = Console()
 p = PathExtended(r'{path}').absolute()
 try:
     from machineconfig.utils.files.read import Read
+    from machineconfig.utils.accessories import pprint
     dat = Read.read(p)
     if isinstance(dat, dict):
         panel_title = f"📄 File Data: {{p.name}}"
@@ -61,15 +62,14 @@ except Exception as e:
 
 
 
-def main(
+def croshell(
+    path: Annotated[Optional[str], typer.Argument(help="read a file.")] = "",
     python: Annotated[bool, typer.Option("--python", "-p", help="flag to use python over IPython.")] = False,
-    fzf: Annotated[bool, typer.Option("--fzf", "-F", help="search with fuzzy finder for python scripts and run them")] = False,
-    ve: Annotated[Optional[str], typer.Option("--ve", "-v", help="virtual enviroment to use, defaults to activated ve, if existed, else ve.")] = None,
     profile: Annotated[Optional[str], typer.Option("--profile", "-P", help="ipython profile to use, defaults to default profile.")] = None,
-    read: Annotated[str, typer.Option("--read", "-r", help="read a binary file.")] = "",
     jupyter: Annotated[bool, typer.Option("--jupyter", "-j", help="run in jupyter interactive console")] = False,
     streamlit_viewer: Annotated[bool, typer.Option("--stViewer", "-s", help="view in streamlit app")] = False,
     visidata: Annotated[bool, typer.Option("--visidata", "-V", help="open data file in visidata")] = False,
+    local: Annotated[bool, typer.Option("--local", "-l", help="run in local mode, not in virtual env.")]= False,
 ) -> None:
     # ==================================================================================
     # flags processing
@@ -78,7 +78,7 @@ def main(
     ipython_profile: Optional[str] = profile
     file_obj = PathExtended.cwd()  # initialization value, could be modified according to args.
 
-    if fzf:
+    if path == ".":
         text = "🔍 Searching for Python files..."
         console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
         options = [str(item) for item in PathExtended.cwd().search("*.py", r=True)]
@@ -88,7 +88,7 @@ def main(
         text = f"📄 Selected file: {PathExtended(file_selected).name}"
         console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
 
-    elif read != "":
+    elif path != "" and path is not None:
         if streamlit_viewer:
             #             text = "📊 STARTING STREAMLIT VIEWER"
             #             console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
@@ -100,7 +100,7 @@ def main(
             # """
             #             PROGRAM_PATH.write_text(data=final_program, encoding="utf-8")
             return None
-        file_obj = PathExtended(str(read).lstrip()).expanduser().absolute()
+        file_obj = PathExtended(str(path).lstrip()).expanduser().absolute()
         program = get_read_data_pycode(str(file_obj))
         text = f"📄 Reading data from: {file_obj.name}"
         console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
@@ -141,15 +141,24 @@ from pathlib import Path
     else:
         if interpreter == "ipython": profile = f" --profile {ipython_profile} --no-banner"
         else: profile = ""
-        fire_line = f"uv run --python 3.13 --with machineconfig[plot] {interpreter} {interactivity} {profile} {str(pyfile)}"
+        if local:
+            from machineconfig.utils.source_of_truth import LIBRARY_ROOT
+            repo_root = LIBRARY_ROOT.parent.parent
+            if repo_root.parent.name == "code" and repo_root.name == "machineconfig" and repo_root.exists() and repo_root.is_dir():
+                ve_line = f"--project {str(repo_root)}"
+            else:
+                console.print(Panel("❌ Could not determine the local machineconfig repo root. Please ensure the `REPO_ROOT` in `source_of_truth.py` is correctly set to the local path of the machineconfig repo, or do not use the `--local` flag.", title="Error", border_style="red"))
+                return
+        else: ve_line = """--with "machineconfig[plot]>=5.72" """
+        fire_line = f"uv run --python 3.14 {ve_line} {interpreter} {interactivity} {profile} {str(pyfile)}"
 
     from machineconfig.utils.code import run_shell_script
-    run_shell_script(fire_line)
+    run_shell_script(fire_line, clean_env=False)
 
 
-def arg_parser() -> None:
-    typer.run(main)
+def main() -> None:
+    typer.run(croshell)
 
 
 if __name__ == "__main__":
-    arg_parser()
+    main()
