@@ -12,7 +12,7 @@ from machineconfig.utils.options import choose_from_options
 from machineconfig.utils.path_helper import match_file_name, sanitize_path
 from machineconfig.utils.path_extended import PathExtended
 from machineconfig.utils.accessories import get_repo_root, randstr
-from machineconfig.scripts.python.fire_jobs_args_helper import FireJobArgs, extract_kwargs, parse_fire_args_from_context
+from machineconfig.scripts.python.helpers_fire_command.fire_jobs_args_helper import FireJobArgs, extract_kwargs, parse_fire_args_from_context
 
 import platform
 from typing import Optional, Annotated
@@ -26,7 +26,7 @@ def route(args: FireJobArgs, fire_args: str = "") -> None:
         suffixes = {".py", ".sh", ".ps1"}
         choice_file = match_file_name(sub_string=args.path, search_root=PathExtended.cwd(), suffixes=suffixes)
     elif path_obj.is_dir():
-        from machineconfig.scripts.python.helpers.helpers4 import search_for_files_of_interest
+        from machineconfig.scripts.python.helpers_fire.helpers4 import search_for_files_of_interest
         print(f"🔍 Searching recursively for Python, PowerShell and Shell scripts in directory `{path_obj}`")
         files = search_for_files_of_interest(path_obj)
         print(f"🔍 Got #{len(files)} results.")
@@ -46,7 +46,10 @@ def route(args: FireJobArgs, fire_args: str = "") -> None:
     # =========================  preparing kwargs_dict
     if choice_file.suffix == ".py":
         kwargs_dict = extract_kwargs(args)  # This now returns empty dict, but kept for compatibility
-        activate_ve_line = get_ve_activate_line(ve_root=args.ve or ve_root_from_file or "$HOME/code/machineconfig/.venv")
+        ve_root = args.ve or ve_root_from_file
+        if ve_root is None:
+            raise ValueError(f"Could not determine virtual environment for file {choice_file}. Please ensure it is within a recognized project structure or specify the `--ve` option.")
+        activate_ve_line = get_ve_activate_line(ve_root=ve_root)
     else:
         activate_ve_line = ""
         kwargs_dict = {}
@@ -55,13 +58,13 @@ def route(args: FireJobArgs, fire_args: str = "") -> None:
     # =========================  choosing function to run
     choice_function: Optional[str] = None  # Initialize to avoid unbound variable
     if args.choose_function:
-        from machineconfig.scripts.python.fire_jobs_route_helper import choose_function_or_lines
+        from machineconfig.scripts.python.helpers_fire_command.fire_jobs_route_helper import choose_function_or_lines
         choice_function, choice_file, kwargs_dict = choose_function_or_lines(choice_file, kwargs_dict)
     else:
         choice_function = args.function
 
     if choice_file.suffix == ".py":
-        from machineconfig.scripts.python.fire_jobs_route_helper import get_command_streamlit
+        from machineconfig.scripts.python.helpers_fire_command.fire_jobs_route_helper import get_command_streamlit
         if args.streamlit:  exe = get_command_streamlit(choice_file, args.environment, repo_root)
         elif args.interactive is False: exe = "python"
         elif args.jupyter: exe = "jupyter-lab"
@@ -72,7 +75,7 @@ def route(args: FireJobArgs, fire_args: str = "") -> None:
 
     if args.module or (args.debug and args.choose_function):  # because debugging tools do not support choosing functions and don't interplay with fire module. So the only way to have debugging and choose function options is to import the file as a module into a new script and run the function of interest there and debug the new script.
         assert choice_file.suffix == ".py", f"File must be a python file to be imported as a module. Got {choice_file}"
-        from machineconfig.scripts.python.helpers.helpers4 import get_import_module_code
+        from machineconfig.scripts.python.helpers_fire.helpers4 import get_import_module_code
         import_line = get_import_module_code(str(choice_file))
         if repo_root is not None:
             repo_root_add = f"""sys.path.append(r'{repo_root}')"""
@@ -193,7 +196,7 @@ python -m machineconfig.cluster.templates.cli_click --file {choice_file} """
     run_shell_script(command)
 
 
-def main(
+def fire(
     ctx: typer.Context,
     path: Annotated[str, typer.Argument(help="Path to the Python file to run")] = ".",
     function: Annotated[Optional[str], typer.Argument(help="Function to run")] = None,
@@ -256,17 +259,16 @@ def main(
         sys.exit(1)
 
 
-def main_from_parser():
-    # from trogon.typer import init_tui
-    # from trogon.typer import init_tui
+def get_app():
     from typer import Typer
-
     app = Typer(add_completion=False)
-    app.command(context_settings={"allow_extra_args": True, "allow_interspersed_args": False})(main)
-    # typer.run(main)
-    # init_tui(app)
+    app.command(context_settings={"allow_extra_args": True, "allow_interspersed_args": False})(fire)
+    return app
+
+def main():
+    app = get_app()
     app()
 
 
 if __name__ == "__main__":
-    main_from_parser()
+    pass
