@@ -19,7 +19,7 @@ for better user experience with checkbox selections.
 
 import sys
 from pathlib import Path
-from typing import cast
+# from typing import cast
 import platform
 
 import questionary
@@ -29,14 +29,13 @@ from rich.panel import Panel
 from rich.text import Text
 from machineconfig.utils.code import run_shell_script
 
-_ = cast
+# _ = cast
 console = Console()
 
 
 def display_header() -> None:
     from machineconfig.utils.installer import get_machineconfig_version
     from rich.align import Align
-    from rich.padding import Padding
 
     # Fancy ASCII art header
     ascii_art = """
@@ -57,23 +56,16 @@ def display_header() -> None:
     subtitle = "🎯 Your digital life manager. Dotfiles, data, code and more."
     bug_report = "🐛 Please report bugs to Alex Al-Saffar @ https://github.com/thisismygitrepo/machineconfig"
 
-    # Create styled texts
-    ascii_text = Text(ascii_art, style="bold cyan")
-    title_text = Text(title, style="bold bright_magenta")
-    subtitle_text = Text(subtitle, style="italic bright_blue")
-    bug_text = Text(bug_report, style="dim white")
-
-    # Create panel content with proper alignment
-    with console.capture() as capture:
-        console.print(ascii_text)
-        console.print()
-        console.print(Align.center(title_text))
-        console.print(Align.center(subtitle_text))
-        console.print()
-        console.print(Align.center(bug_text))
-
-    panel_content = capture.get()
-    console.print(Panel(Padding(panel_content, (1, 2)), border_style="bright_cyan", padding=(1, 2)))
+    # Print ASCII art
+    console.print(Text(ascii_art, style="bold cyan"))
+    console.print()
+    
+    # Print centered text elements
+    console.print(Align.center(Text(title, style="bold bright_magenta")))
+    console.print(Align.center(Text(subtitle, style="italic bright_blue")))
+    console.print()
+    console.print(Align.center(Text(bug_report, style="dim white")))
+    console.print()
 def display_completion_message() -> None:
     completion_text = Text("INSTALLATION COMPLETE", style="bold green")
     subtitle_text = Text("System setup finished successfully", style="italic green")
@@ -104,64 +96,46 @@ def display_dotfiles_instructions() -> None:
 def get_installation_choices() -> list[str]:
     """Get user choices for installation options."""
     choices = [
-        Choice(value="upgrade_system", title="🔄 Upgrade System Packages        - Update all system packages", checked=False),
-        Choice(value="ESSENTIAL_SYSTEM", title="📥 Install Apps                    - Install base system applications", checked=False),
-        Choice(value="ESSENTIAL", title="⚡ Install CLI Apps               - Command-line tools installation", checked=False),
-        Choice(value="DEV_SYSTEM", title="🛠️  Install Development Tools      - rust, libssl-dev, ffmpeg, wezterm, brave, code", checked=False),
-        Choice(value="TerminalEyeCandy", title="🎨 Install ASCII Art Libraries    - Terminal visualization tools", checked=False),
-        Choice(value="install_repos", title="🐍 Install Repos                - Set up Python environment and repositories permanently.", checked=False),
-        Choice(value="install_ssh_server", title="🔒 Install SSH Server             - Set up remote access", checked=False),
-        Choice(value="install_shell_profile", title="🐚 Configure Shell Profile         - Source machineconfig shell initialization", checked=False),
-        Choice(value="retrieve_repositories", title="📚 Retrieve Repositories          - Clone repositories to ~/code", checked=False),
-        Choice(value="retrieve_data", title="💾 Retrieve Data                  - Backup restoration", checked=False),
+        Choice(value="install_repos", title="🐍 Install machineconfig.", checked=False),
+        Choice(value="ESSENTIAL_SYSTEM", title="📥 Install Essential System Packages.", checked=False),
+        Choice(value="ESSENTIAL", title="⚡ Install CLI apps essentials", checked=False),
+        Choice(value="DEV_SYSTEM", title="🛠️  Install CLI apps development.", checked=False),
+        Choice(value="TerminalEyeCandy", title="🎨 Install CLI apps terminal eye candy.", checked=False),
+        Choice(value="install_ssh_server", title="🔒 Install SSH Server", checked=False),
+        Choice(value="install_shell_profile", title="🐚 Configure Shell Profile.", checked=False),
+        Choice(value="retrieve_repositories", title="📚 Retrieve Repositories", checked=False),
+        Choice(value="retrieve_data", title="💾 Retrieve Data.", checked=False),
     ]
     # Add Windows-specific options
     if platform.system() == "Windows":
-        choices.append(Choice(value="install_windows_desktop", title="💻 Install Windows Desktop Apps   - Brave, Windows Terminal, PowerShell, VSCode (Windows only)", checked=False))
+        choices.append(Choice(value="install_windows_desktop", title="💻 Install Windows Desktop Apps   - Install nerd fonts and set WT config.", checked=False))
     selected = questionary.checkbox("Select the installation options you want to execute:", choices=choices, show_description=True).ask()
     return selected or []
 
 
 def execute_installations(selected_options: list[str]) -> None:
-    if platform.system() == "Windows":
-        from machineconfig import setup_windows as module
-        script_path = Path(module.__file__).parent / "ve.ps1"
-        run_shell_script(script_path.read_text(encoding="utf-8"))
-    else:
-        from machineconfig import setup_linux as module
-        script_path = Path(module.__file__).parent / "ve.sh"
-        run_shell_script(script_path.read_text(encoding="utf-8"))
-
     for maybe_a_group in selected_options:
         if maybe_a_group in ("ESSENTIAL", "DEV", "ESSENTIAL_SYSTEM", "DEV_SYSTEM", "TerminalEyeCandy"):
             console.print(Panel("⚡ [bold bright_yellow]CLI APPLICATIONS[/bold bright_yellow]\n[italic]Command-line tools installation[/italic]", border_style="bright_yellow"))
             console.print("🔧 Installing CLI applications", style="bold cyan")
             try:
                 from machineconfig.utils.installer_utils.installer import main as devops_devapps_install_main
-                devops_devapps_install_main(group=maybe_a_group)  # type: ignore
+                devops_devapps_install_main(group=True, which=maybe_a_group, interactive=False)
                 console.print("✅ CLI applications installed successfully", style="bold green")
             except Exception as e:
                 console.print(f"❌ Error installing CLI applications: {e}", style="bold red")
             run_shell_script(". $HOME/.bashrc")
 
-    if "upgrade_system" in selected_options:
-        if platform.system() == "Windows":
-            console.print("❌ System upgrade is not applicable on Windows via this script.", style="bold red")
-        elif platform.system() == "Linux":
-            console.print(Panel("🔄 [bold magenta]SYSTEM UPDATE[/bold magenta]\n[italic]Package management[/italic]", border_style="magenta"))
-            run_shell_script("sudo nala upgrade -y")
-        else:
-            console.print(f"❌ System upgrade not supported on {platform.system()}.", style="bold red")
     if "install_repos" in selected_options:
         console.print(Panel("🐍 [bold green]PYTHON ENVIRONMENT[/bold green]\n[italic]Virtual environment setup[/italic]", border_style="green"))
+        import platform
         if platform.system() == "Windows":
-            from machineconfig.setup_windows import REPOS
+            run_shell_script(r"""$HOME\.local\bin\uv.exe tool install machineconfig>=5.72""")
         else:
-            from machineconfig.setup_linux import REPOS
-        run_shell_script(REPOS.read_text(encoding="utf-8"))
-
+            run_shell_script("""$HOME/.local/bin/uv tool install machineconfig>=5.72""")
     if "install_ssh_server" in selected_options:
         console.print(Panel("🔒 [bold red]SSH SERVER[/bold red]\n[italic]Remote access setup[/italic]", border_style="red"))
+        import platform
         if platform.system() == "Windows":
             powershell_script = """Write-Host "🔧 Installing and configuring SSH server..."
 Add-WindowsCapability -Online -Name OpenSSH.Server~~~~0.0.1.0
@@ -175,22 +149,22 @@ Set-Service -Name sshd -StartupType 'Automatic'"""
         console.print(Panel("🐚 [bold green]SHELL PROFILE[/bold green]\n[italic]Shell configuration setup[/italic]", border_style="green"))
         console.print("🔧 Configuring shell profile", style="bold cyan")
         try:
-            from machineconfig.profile.shell import create_default_shell_profile
-            create_default_shell_profile(method="copy")
+            from machineconfig.profile.create_shell_profile import create_default_shell_profile
+            create_default_shell_profile()
             console.print("✅ Shell profile configured successfully", style="bold green")
         except Exception as e:
             console.print(f"❌ Error configuring shell profile: {e}", style="bold red")
 
     if "retrieve_repositories" in selected_options:
         console.print(Panel("📚 [bold bright_magenta]REPOSITORIES[/bold bright_magenta]\n[italic]Project code retrieval[/italic]", border_style="bright_magenta"))
-        from machineconfig.scripts.python import repos
-        repos.clone(directory=str(Path.home() / "code"), cloud="odg1")
+        from machineconfig.scripts.python.devops_helpers import cli_repos
+        cli_repos.clone(directory=str(Path.home() / "code"), cloud="odg1")
 
     if "retrieve_data" in selected_options:
         console.print(Panel("💾 [bold bright_cyan]DATA RETRIEVAL[/bold bright_cyan]\n[italic]Backup restoration[/italic]", border_style="bright_cyan"))
         console.print("🔧 Retrieving backup data", style="bold cyan")
         try:
-            from machineconfig.scripts.python.devops_backup_retrieve import main_backup_retrieve
+            from machineconfig.scripts.python.devops_helpers.devops_backup_retrieve import main_backup_retrieve
             main_backup_retrieve(direction="RETRIEVE")
             console.print("✅ Backup data retrieved successfully", style="bold green")
         except Exception as e:
@@ -214,8 +188,7 @@ def main() -> None:
     if not proceed:
         console.print("❌ Installation cancelled.", style="bold red")
         sys.exit(0)
-    execute_installations(selected_options)
-    display_dotfiles_instructions()
+    execute_installations(selected_options=selected_options)
     display_completion_message()
 
 
