@@ -56,17 +56,19 @@ def main_with_parser():
 
 
 def main(
-    which: Optional[str] = typer.Option(None, "--which", "-w", help="Comma-separated list of program names to install."),
-    group: Optional[PACKAGE_GROUPS] = typer.Option(None, "--group", "-g", help=f"Group name (one of {list(get_args(PACKAGE_GROUPS))})"),
+    which: Optional[str] = typer.Argument(None, help="Comma-separated list of program/groups names to install (if --group flag is set)."),
+    group: bool = typer.Option(False, "--group", "-g", help="Treat 'which' as a group name. A group is bundle of apps."),
     interactive: bool = typer.Option(False, "--interactive", "-ia", help="Interactive selection of programs to install."),
 ) -> None:
-    if which is not None:
-        return install_clis(clis_names=[x.strip() for x in which.split(",") if x.strip() != ""])
-    if group is not None:
-        return install_group(package_group=group)
     if interactive:
         return install_interactively()
-    typer.echo("❌ You must provide either --which, --group, or --interactive/-ia option.")
+    if which is not None:
+        if group:
+            for a_group in [x.strip() for x in which.split(",") if x.strip() != ""]:
+                return install_group(package_group=a_group)
+        else:
+            return install_clis(clis_names=[x.strip() for x in which.split(",") if x.strip() != ""])
+    typer.echo("❌ You must provide either a program name/group name, or use --interactive/-ia option.")
     import click
     ctx = click.get_current_context()
     typer.echo(ctx.get_help())
@@ -82,13 +84,11 @@ def install_interactively():
     installer_options = []
     for x in installers:
         installer_options.append(Installer(installer_data=x).get_description())
-    
     # Build category options and maintain a mapping from display text to actual category name
     category_display_to_name: dict[str, str] = {}
     for group_name, group_values in PACKAGE_GROUP2NAMES.items():
         display = f"📦 {group_name:<20}" + "   --   " + f"{'|'.join(group_values):<60}"
         category_display_to_name[display] = group_name
-    
     options_system = get_installers_system_groups()
     for item in options_system:
         display = f"📦 {item['appName']:<20}   --   {item['doc']:<60}"
@@ -114,7 +114,7 @@ def install_interactively():
         console.print(panel)
 
 
-def install_group(package_group: PACKAGE_GROUPS):
+def install_group(package_group: str):
     panel = Panel(f"[bold yellow]Installing programs from category: [green]{package_group}[/green][/bold yellow]", title="[bold blue]📦 Category Installation[/bold blue]", border_style="blue", padding=(1, 2))
     console.print(panel)
     from machineconfig.utils.installer import get_installers, install_bulk
@@ -181,6 +181,17 @@ def install_clis(clis_names: list[str]):
     return None
 
 
+def install_if_missing(which: str):
+    from machineconfig.utils.installer_utils.installer_abc import check_tool_exists
+    exists = check_tool_exists(which)
+    if exists:
+        print(f"✅ {which} is already installed.")
+        return
+    print(f"⏳ {which} not found. Installing...")
+    from machineconfig.utils.installer_utils.installer import main
+    main(which=which)
+
+
 if __name__ == "__main__":
     from machineconfig.utils.schemas.installer.installer_types import InstallerData
     from machineconfig.utils.installer_utils.installer_class import Installer
